..  venco.py introdcution file created on September 15, 2020
    Licensed under CC BY 4.0: https://creativecommons.org/licenses/by/4.0/deed.en

.. _codestyle:

Codestyle Guideline
===================================

- Coding standard: PEP-8 with the exception of UpperCamelCase for class objects
- Autoformatting: black
- Linter: flake8
- Docstrings format code: Google
- Docstrings format testing: GWT (Given-When-Then)
- We aim at reaching a codestyle status where code width keeps below 80 columns
- We aim at reaching a codestyle status where print-statements, docstrings and documentation keeps below 120 columns
